@@ -45,7 +45,6 @@ enum op {
 static int _process_channel(const gchar *channel_directory, GKeyFile *kf, const char *identifier,
                             enum op op, struct channel_configuration *defaults,
                             enclosure_filter *filter);
-static void usage(void);
 static void version(void);
 static GKeyFile *_configuration_file_open(const gchar *rcfile);
 static void _configuration_file_close(GKeyFile *kf);
@@ -77,7 +76,7 @@ static gchar *filter_regex = NULL;
 int main(int argc, char **argv)
 {
   enum op op = OP_UPDATE;
-  int i, len;
+  int i;
   int ret = 0;
   gchar **groups;
   gchar *channeldir;
